@@ -209,6 +209,10 @@ class MultipleSelect(Field):
         return value
 
     def value__set(self, values):
+        if not values:
+            self._forced_values = None
+        elif self._forced_values is not NoValue:
+            self._forced_values = NoValue
         str_values = [utils.stringify(value) for value in values]
         self.selectedIndices = []
         for i, (option, checked, text) in enumerate(self.options):
@@ -332,8 +336,8 @@ class Submit(Field):
     value = property(value__get, value__set)
 
     def value_if_submitted(self):
-        # TODO: does this ever get set?
-        return self._value
+        # parsed value of the empty string
+        return self._value or ''
 
 
 Field.classes['submit'] = Submit
@@ -352,6 +356,8 @@ Field.classes['file'] = File
 
 Field.classes['text'] = Text
 
+Field.classes['search'] = Text
+
 Field.classes['email'] = Email
 
 Field.classes['password'] = Text
@@ -405,7 +411,7 @@ class Form(object):
 
     _tag_re = re.compile(r'<(/?)([a-z0-9_\-]*)([^>]*?)>', re.I)
     _label_re = re.compile(
-        '''<label\s+(?:[^>]*)for=(?:"|')([a-z0-9_\-]+)(?:"|')(?:[^>]*)>''',
+        r'''<label\s+(?:[^>]*)for=(?:"|')([a-z0-9_\-]+)(?:"|')(?:[^>]*)>''',
         re.I)
 
     FieldClass = Field
